{% extends 'djangomaster/_single_col.html' %}


{% block page_title %}Settings{% endblock %}

{% block extra_css %}
<style>
    .settings-list {
        font-size: 80%
    }

    .settings-key,
    .settings-key:visited {
        overflow-x: hidden;
        text-overflow: ellipsis;
        color: inherit;
        display: block;
        outline: 0 !important;
    }

    .settings-key:target {
        color: #3b8bba;
    }
</style>
{% endblock %}

{% block content %}

    <p>&nbsp;</p>

    <div class="pure-g settings-list">

        {% for key, value in settings_list %}
            <div class="pure-u-2-5">
                <a id="{{key}}" href="#{{key}}" title="{{key}}" class="settings-key">{{ key }}</a>
            </div>
            <div class="pure-u-3-5">{{ value }}</div>
        {% endfor %}

    </div>

{% endblock %}

