{% load staticfiles %}

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8" />
    <title>Django master</title>

    <link rel="stylesheet" href="{% static 'djangomaster/css/pure-min.css' %}" />
    <link rel="stylesheet" href="{% static 'djangomaster/css/side-menu.css' %}" />
    <link rel="stylesheet" href="{% static 'djangomaster/css/pure-theme.css' %}" />

    <style>
        [v-cloak]{ visibility: hidden; }
        .footer:empty { display: none; }
    </style>
    {% block extra_css %}{% endblock %}
</head>
<body>

    <div id="layout">
        {# Menu toggle #}
        <a href="#menu" id="menuLink" class="menu-link">
            {# Hamburger icon #}
            <span></span>
        </a>

        <div id="menu">
            {% include 'djangomaster/includes/_side_menu.html' %}
        </div>

        <div id="main">
            <div class="header">
                <h1>{% block page_title %}{% endblock %}</h1>
                <h2>{% block page_subtitle %}{% endblock %}</h2>
            </div>

            <div class="content">
                {% block content %}{% endblock %}
            </div>

            <div class="footer">{% block footer %}{% endblock %}</div>
        </div>
    </div>

    <script src="{% static 'djangomaster/js/jquery.min.js' %}"></script>
    <script src="{% static 'djangomaster/js/vue.min.js' %}"></script>
    <script src="{% static 'djangomaster/js/ui.js' %}"></script>
    {% block extra_js %}{% endblock %}
</body>
</html>
