{% extends 'djangomaster/_single_col.html' %}
{% load i18n %}
{% load url from future %}

{% block page_title %}South{% endblock %}


{% block content %}

    {% if not settings.SOUTH_IS_INSTALLED %}
        <p>{% trans "South isn't in INSTALLED_APPS" %} </p>
    {% else %}

        <div class="pure-5-5">

            {% for app_name, migrations in history_list.items %}
            <table class="table pure-table">
                <cation>{{app_name}}</cation>
                <tbody>
                    {% for migration in migrations %}
                        <tr class="{% cycle 'pure-table-odd' 'pure-table-even' %}">
                            <td>{{migration.name}}</td>
                            <td>{{migration.applied}}</td>
                        </tr>
                    {% endfor %}
                </tbody>
            </table>
            {% empty %}
                <p>{% trans 'No migrations to be displayed' %}</p>
            {% endfor %}

        </div>

    {% endif %}

{% endblock %}
