{% load i18n %}
{% load url from future %}

<div class="pure-menu pure-menu-open">
    <a class="pure-menu-heading" href="{% url 'djangomaster:home' %}">Master</a>

    {% with selected_class="pure-menu-selected" %}

        <ul>
            <li {% ifequal menu_item 'home' %}class="{{selected_class}}"{% endifequal %}>
                <a href="{% url 'djangomaster:home' %}">{% trans 'Home' %}</a>
            </li>

            <li class="menu-item-divided {% ifequal menu_item 'routes' %}{{selected_class}}{% endifequal %}">
                <a href="{% url 'djangomaster:routes' %}">{% trans 'Routes' %}</a>
            </li>

            <li class="menu-item-divided {% ifequal menu_item 'signals' %}{{selected_class}}{% endifequal %}">
                <a href="{% url 'djangomaster:signals' %}">{% trans 'Signals' %}</a>
            </li>

            <li {% ifequal menu_item 'settings' %}class="{{selected_class}}"{% endifequal %}>
                <a href="{% url 'djangomaster:settings' %}">{% trans 'Settings' %}</a>
            </li>

            <li {% ifequal menu_item 'pylint' %}class="{{selected_class}}"{% endifequal %}>
                <a href="{% url 'djangomaster:pylint' %}">{% trans 'Pylint' %}</a>
            </li>

            <li {% ifequal menu_item 'jslint' %}class="{{selected_class}}"{% endifequal %}>
                <a href="{% url 'djangomaster:jslint' %}">{% trans 'JSlint' %}</a>
            </li>

            <li {% ifequal menu_item 'test' %}class="{{selected_class}}"{% endifequal %}>
                <a href="{% url 'djangomaster:test' %}">{% trans 'Test' %}</a>
            </li>

            <li {% ifequal menu_item 'south' %}class="{{selected_class}}"{% endifequal %}>
                <a href="{% url 'djangomaster:south' %}">{% trans 'South' %}</a>
            </li>
        </ul>

    {% endwith %}
</div>
